document.addEventListener("DOMContentLoaded", () => {
  const editor = document.getElementById("editor");
  const themeToggle = document.getElementById("theme-toggle");
  const widthSlider = document.getElementById("width-slider");
  const sessionLength = document.getElementById("session-length");
  const keystrokeInterval = document.getElementById("keystroke-interval");
  const startSession = document.getElementById("start-session");
  const energyBar = document.getElementById("energy-bar");

  // Load saved content
  editor.value = localStorage.getItem("content") || "";
  editor.addEventListener("input", () => {
    localStorage.setItem("content", editor.value);
  });

  // Theme toggle
  themeToggle.addEventListener("click", () => {
    document.body.classList.toggle("dark-mode");
    localStorage.setItem(
      "darkMode",
      document.body.classList.contains("dark-mode"),
    );
  });

  // Load theme preference
  if (localStorage.getItem("darkMode") === "true") {
    document.body.classList.add("dark-mode");
  }

  // Line width control
  widthSlider.addEventListener("input", () => {
    editor.style.maxWidth = `${widthSlider.value}ch`;
  });

  // Fullscreen toggle
  document.addEventListener("keydown", (e) => {
    if (e.shiftKey && e.key === "F") {
      editor.classList.toggle("fullscreen");
      e.preventDefault();
    }
  });

  let sessionTimer;
  let keystrokeTimer;
  let lastKeystroke = Date.now();

  const startWritingSession = () => {
    const sessionDuration = sessionLength.value * 60 * 1000;
    const keystrokeDuration = keystrokeInterval.value * 1000;

    editor.focus();
    energyBar.style.display = "block";
    energyBar.style.width = "100%";

    sessionTimer = setTimeout(() => {
      alert("Writing session complete!");
      resetSession();
    }, sessionDuration);

    const checkKeystroke = () => {
      const timeSinceLastKeystroke = Date.now() - lastKeystroke;
      const percentage =
        100 - (timeSinceLastKeystroke / keystrokeDuration) * 100;
      energyBar.style.width = `${Math.max(0, percentage)}%`;
      energyBar.style.display = percentage > 50 ? "none" : "block";

      if (timeSinceLastKeystroke > keystrokeDuration) {
        alert("Keep writing!");
        lastKeystroke = Date.now();
      }
    };

    keystrokeTimer = setInterval(checkKeystroke, 100);

    editor.addEventListener("keydown", () => {
      lastKeystroke = Date.now();
    });
  };

  const resetSession = () => {
    clearTimeout(sessionTimer);
    clearInterval(keystrokeTimer);
    energyBar.style.display = "none";
  };

  startSession.addEventListener("click", () => {
    resetSession();
    startWritingSession();
  });
});
